PyXMake Developer Guide: PyXMake.VTL.stm_make.win_mcodac Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.win_mcodac Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.win_mcodac:

## Public Attributes
list | includes
| modules = os.path.join(self.base_path,"include",Utility.GetPlatform(), Utility.GetArchitecture())
| libpaths = os.path.join(self.base_path,"lib",Utility.GetPlatform(), Utility.GetArchitecture())
| libs = VTL.GetLinkDependency(self._KEY_OPT, self._MAKE_OPT["Fortran"], Utility.GetArchitecture())
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_fortran
int | verbose = 0
str | source_path = ''
str | output_file_path = ''
str | base_path = ''
| scratch_path = os.getcwd()
str | btype = 'static'
| libs = None
| includes = None
| libpaths = None
| modules = None
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_fortran
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Static Protected Attributes
int | _KEY_OPT = 0
str | _PACKAGE_NAME = 'mcd_core'
| _INPUT_FILES = GetSourceCode(_KEY_OPT)
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_fortran
str | _PACKAGE_NAME = ''
list | _INPUT_FILES = []

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_fortran
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_fortran
str | description = "Runs the build process of Fortran source code using the Intel Fortran Compiler through Python."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()
Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_fortran
dict | _MAKE_OPT = {"Python":0, "Java":1, "Fortran":2}

## Detailed Description

    Runs the build process for MCODAC on Windows.

Definition at line 785 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.win_mcodac._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 796 of file stm_make.py.

## Member Data Documentation

## ◆ _INPUT_FILES

PyXMake.VTL.stm_make.win_mcodac._INPUT_FILES = GetSourceCode(_KEY_OPT)
| staticprotected

Definition at line 794 of file stm_make.py.

## ◆ _KEY_OPT

int PyXMake.VTL.stm_make.win_mcodac._KEY_OPT = 0
| staticprotected

Definition at line 791 of file stm_make.py.

## ◆ _PACKAGE_NAME

str PyXMake.VTL.stm_make.win_mcodac._PACKAGE_NAME = 'mcd_core'
| staticprotected

Definition at line 792 of file stm_make.py.

## ◆ includes

list PyXMake.VTL.stm_make.win_mcodac.includes

Initial value:
= [os.path.join(self.base_path,"include",Utility.GetPlatform(),Utility.GetArchitecture(), x)
for x in VTL.GetIncludeDirectory(self.base_path, 0, 4, Utility.GetArchitecture())],

Definition at line 800 of file stm_make.py.

## ◆ libpaths

PyXMake.VTL.stm_make.win_mcodac.libpaths = os.path.join(self.base_path,"lib",Utility.GetPlatform(), Utility.GetArchitecture())

Definition at line 803 of file stm_make.py.

## ◆ libs

PyXMake.VTL.stm_make.win_mcodac.libs = VTL.GetLinkDependency(self._KEY_OPT, self._MAKE_OPT["Fortran"], Utility.GetArchitecture())

Definition at line 804 of file stm_make.py.

## ◆ modules

PyXMake.VTL.stm_make.win_mcodac.modules = os.path.join(self.base_path,"include",Utility.GetPlatform(), Utility.GetArchitecture())

Definition at line 802 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py